pkglts\.option\.coveralls package
=================================

Submodules
----------

pkglts\.option\.coveralls\.config module
----------------------------------------

.. automodule:: pkglts.option.coveralls.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.coveralls\.handlers module
------------------------------------------

.. automodule:: pkglts.option.coveralls.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.coveralls
    :members:
    :undoc-members:
    :show-inheritance:
